aboutsummaryrefslogtreecommitdiff
path: root/graphics/netpbm
diff options
context:
space:
mode:
authorDirk Meyer <dinoex@FreeBSD.org>2012-04-23 18:28:17 +0000
committerDirk Meyer <dinoex@FreeBSD.org>2012-04-23 18:28:17 +0000
commitc66b72c398dd5b5e8d10aba6a637632243826276 (patch)
tree17aac8fdbd374fc5f7da4f9bbe533e0ee7a276f6 /graphics/netpbm
parentff4f59ba38ba6650fa5925fb8999ee8618bb0c31 (diff)
downloadports-c66b72c398dd5b5e8d10aba6a637632243826276.tar.gz
ports-c66b72c398dd5b5e8d10aba6a637632243826276.zip
- fix includes
Notes
Notes: svn path=/head/; revision=295328
Diffstat (limited to 'graphics/netpbm')
-rw-r--r--graphics/netpbm/files/patch-pnmtopng.c25
1 files changed, 18 insertions, 7 deletions
diff --git a/graphics/netpbm/files/patch-pnmtopng.c b/graphics/netpbm/files/patch-pnmtopng.c
index 14ed8ff7c123..48a40c0e0e66 100644
--- a/graphics/netpbm/files/patch-pnmtopng.c
+++ b/graphics/netpbm/files/patch-pnmtopng.c
@@ -1,6 +1,17 @@
---- converter/other/pnmtopng.c.orig 2009-09-03 17:34:36.000000000 +0200
-+++ converter/other/pnmtopng.c 2010-05-21 10:45:59.000000000 +0200
-@@ -69,7 +69,7 @@
+--- converter/other/pnmtopng.c.orig 2011-09-25 20:51:44.000000000 +0200
++++ converter/other/pnmtopng.c 2012-04-23 20:23:10.000000000 +0200
+@@ -61,7 +61,9 @@
+ #include <assert.h>
+ #include <string.h> /* strcat() */
+ #include <limits.h>
+-#include <png.h> /* includes zlib.h and setjmp.h */
++#include <png.h>
++#include <zlib.h>
++#include <pngpriv.h>
+ #include "pnm.h"
+ #include "pngtxt.h"
+ #include "shhopt.h"
+@@ -69,7 +71,7 @@
#include "nstring.h"
#include "version.h"
@@ -8,8 +19,8 @@
+#if 0
#error Your PNG library (<png.h>) is incompatible with this Netpbm source code.
#error You need either an older PNG library (older than 1.4)
- #error newer Netpbm source code (at least 10.48)
-@@ -2611,7 +2611,7 @@
+ #error newer Netpbm source code (at least 10.47.04)
+@@ -2630,7 +2632,7 @@
info_ptr->num_palette = palette_size;
if (trans_size > 0) {
info_ptr->valid |= PNG_INFO_tRNS;
@@ -18,7 +29,7 @@
info_ptr->num_trans = trans_size; /* omit opaque values */
}
/* creating hIST chunk */
-@@ -2648,7 +2648,7 @@
+@@ -2667,7 +2669,7 @@
info_ptr->color_type == PNG_COLOR_TYPE_RGB) {
if (transparent > 0) {
info_ptr->valid |= PNG_INFO_tRNS;
@@ -27,7 +38,7 @@
xelToPngColor_16(transcolor, maxval, png_maxval);
}
} else {
-@@ -2660,10 +2660,10 @@
+@@ -2679,10 +2681,10 @@
if (info_ptr->valid && PNG_INFO_tRNS)
pm_message("Transparent color {gray, red, green, blue} = "
"{%d, %d, %d, %d}",